@@ -1,16 +1,22 @@
 import os
+import io
 import lxml
 import time
 import shutil
 import flask
-import logging
 import pandas as pd
+import logging
+import logging.config
 
 try:
     import ujson as json
 except:
     import json
 
+# setup default config
+with io.open(os.path.join(os.path.dirname(__file__), 'logger.json')) as f:
+    logging.config.dictConfig(json.load(f))
+
 from uuid import uuid4
 from urllib.parse import unquote
 from datetime import datetime
@@ -20,12 +26,12 @@ from flask import request, jsonify, make_response, Response, Response as HttpRes
 from flask_api import status
 
 from label_studio.utils.functions import generate_sample_task
-from label_studio.utils.io import find_dir, find_editor_files, get_temp_dir
+from label_studio.utils.io import find_dir, find_file, find_editor_files
 from label_studio.utils import uploader
 from label_studio.utils.validation import TaskValidator
 from label_studio.utils.exceptions import ValidationError
-from label_studio.utils.functions import generate_sample_task_without_check, data_examples
-from label_studio.utils.misc import exception_treatment, log_config, log, config_line_stripped, get_config_templates
+from label_studio.utils.functions import generate_sample_task_without_check
+from label_studio.utils.misc import exception_treatment, config_line_stripped, get_config_templates
 from label_studio.utils.argparser import parse_input_args
 
 from label_studio.project import Project
@@ -103,12 +109,10 @@ def send_static(path):
     return flask.send_from_directory(static_dir, path)
 
 
-@app.route('/logs')
-def send_log():
-    """ Log access via web
-    """
-    logfile = log_config['handlers']['file']['filename']
-    return Response(open(logfile).read(), mimetype='text/plain')
+@app.errorhandler(ValidationError)
+def validation_error_handler(error):
+    logger.error(error)
+    return str(error), 500
 
 
 @app.route('/')
@@ -242,11 +246,7 @@ def api_render_label_studio():
         return make_response('No config in POST', status.HTTP_417_EXPECTATION_FAILED)
 
     # prepare example
-    examples = data_examples(mode='editor_preview')
-    task_data = {
-        data_key: examples.get(data_type, '')
-        for data_key, data_type in project.extract_data_types(config).items()
-    }
+    task_data = generate_sample_task_without_check(config, mode='editor_preview')
     example_task_data = {
         'id': 1764,
         'data': task_data,
@@ -301,7 +301,11 @@ def api_save_config():
     except Exception as e:
         return make_response(jsonify({'label_config': [str(e)]}), status.HTTP_400_BAD_REQUEST)
 
-    project.update_label_config(label_config)
+    try:
+        project.update_label_config(label_config)
+    except Exception as e:
+        return make_response(jsonify({'label_config': [str(e)]}), status.HTTP_400_BAD_REQUEST)
+
     project.analytics.send(getframeinfo(currentframe()).function)
     return Response(status=status.HTTP_201_CREATED)
 
@@ -429,16 +433,21 @@ def api_export():
     project = project_get_or_create()
     now = datetime.now()
     completion_dir = project.config['output_dir']
-    export_dirname = now.strftime('%Y-%m-%d-%H-%M-%S')
-    with get_temp_dir() as temp_dir:
-        export_dirpath = os.path.join(temp_dir, export_dirname)
-        project.converter.convert(completion_dir, export_dirpath, format=export_format)
-        shutil.make_archive(export_dirpath, 'zip', export_dirpath)
-        export_zipfile = export_dirpath + '.zip'
-        response = send_file(export_zipfile, as_attachment=True)
-        response.headers['filename'] = os.path.basename(export_zipfile)
-        project.analytics.send(getframeinfo(currentframe()).function)
-        return response
+
+    project_export_dir = os.path.join(os.path.dirname(completion_dir), 'export')
+    os.makedirs(project_export_dir, exist_ok=True)
+
+    zip_dir = os.path.join(project_export_dir, now.strftime('%Y-%m-%d-%H-%M-%S'))
+    os.makedirs(zip_dir, exist_ok=True)
+
+    project.converter.convert(completion_dir, zip_dir, format=export_format)
+    shutil.make_archive(zip_dir, 'zip', zip_dir)
+    shutil.rmtree(zip_dir)
+
+    response = send_file(zip_dir+'.zip', as_attachment=True)
+    response.headers['filename'] = os.path.basename(zip_dir+'.zip')
+    project.analytics.send(getframeinfo(currentframe()).function)
+    return response
 
 
 @app.route('/api/projects/1/next/', methods=['GET'])
@@ -530,7 +539,6 @@ def api_completions(task_id):
         completion = request.json
         completion.pop('state', None)  # remove editor state
         completion_id = project.save_completion(task_id, completion)
-        log.info(msg='Completion saved', extra={'task_id': task_id, 'output': request.json})
         # try to train model with new completions
         if project.ml_backend:
             project.ml_backend.update_model(project.get_task(task_id), completion, project.project_obj)
@@ -575,7 +583,6 @@ def api_completion_update(task_id, completion_id):
     completion.pop('state', None)  # remove editor state
     completion['id'] = int(completion_id)
     project.save_completion(task_id, completion)
-    log.info(msg='Completion saved', extra={'task_id': task_id, 'output': request.json})
     project.analytics.send(getframeinfo(currentframe()).function)
     return make_response('ok', 201)
 
@@ -622,6 +629,10 @@ def main():
 
     input_args = parse_input_args()
 
+    # setup logging level
+    if input_args.log_level:
+        logging.root.setLevel(input_args.log_level)
+
     import label_studio.utils.functions
     label_studio.utils.functions.HOSTNAME = 'http://localhost:' + str(input_args.port)
 
@@ -636,6 +647,11 @@ def main():
         if input_args.init:
             Project.create_project_dir(input_args.project_name, input_args)
 
+        if not os.path.exists(input_args.project_name):
+            raise FileNotFoundError(
+                'Project directory "{pdir}" not found. '
+                'Did you miss create it first with `label-studio init {pdir}` ?'.format(pdir=input_args.project_name))
+
     # On `start` command, launch browser if --no-browser is not specified and start label studio server
     if input_args.command == 'start':
         if not input_args.no_browser:
