@@ -54,7 +54,7 @@ def parse_input_args():
     root_parser.add_argument(
         '--input-format', dest='input_format',
         choices=('json', 'json-dir', 'text', 'text-dir', 'image-dir', 'audio-dir'), default='json',
-        help='Input path to task file or directory with tasks')
+        help='Input tasks format. Unless you are using "json" or "json-dir" format, --label-config option is required')
     root_parser.add_argument(
         '-o', '--output-dir', dest='output_dir', type=valid_filepath,
         help='Output directory for completions')
@@ -67,6 +67,10 @@ def parse_input_args():
     root_parser.add_argument(
         '-p', '--port', dest='port', default=8200, type=int,
         help='Server port')
+    root_parser.add_argument(
+        '--log-level', dest='log_level', choices=['DEBUG', 'INFO', 'WARNING', 'ERROR'], default=None,
+        help='Logging level'
+    )
 
     parser = argparse.ArgumentParser(description='Label studio')
 
