@@ -53,7 +53,9 @@ class ProjectObj(object):
 
     def connect(self, ml_backend):
         self.ml_backend = ml_backend
-        self.schema = ml_backend.get_schema(self.label_config, self)
+        self.schema = ml_backend.get_schema(self)
+        if self.schema is None:
+            raise ValueError('Can\'t connect to ML backend because schema was not set')
 
     @property
     def train_job(self):
@@ -453,14 +455,16 @@ class MLBackend(object):
                     logger.debug('Model version has changed: ' + model_version)
                 else:
                     logger.debug('Model version hasn\'t changed: ' + model_version)
-            response = self.api.predict([task], self.model_version, project)
-            if response.is_error:
-                if response.status_code == 404:
-                    logger.info('Can\'t make predictions: model is not found (probably not trained yet)')
+                response = self.api.predict([task], self.model_version, project)
+                if response.is_error:
+                    if response.status_code == 404:
+                        logger.info('Can\'t make predictions: model is not found (probably not trained yet)')
+                    else:
+                        logger.error('Can\'t make predictions: ML backend returns error: ' + response.error_message)
                 else:
-                    logger.error('Can\'t make predictions: ML backend returns error: ' + response.error_message)
+                    return response.response['results']
             else:
-                return response.response['results']
+                logger.warning('ML backend setup returns error: ' + r.error_message)
 
     def update_model(self, task, completion, project):
         if self._api_exists():
@@ -476,18 +480,28 @@ class MLBackend(object):
                     self.save_train_job()
                     logger.debug('Project ' + str(project) + ' successfully updated train job ' + self.train_job)
 
-    def get_schema(self, label_config, project):
+    def validate(self, label_config):
         if self._api_exists():
-            response = self.api.validate(project.label_config)
+            response = self.api.validate(label_config)
             if response.is_error:
-                logger.error('Can\'t infer schema for label config ' + label_config + '. '
-                             'ML backend returns error: ' + response.error_message)
+                if response.status_code == 422:
+                    raise ValidationError(
+                        'ML backend doesn\'t accept current label config ' + label_config +
+                        ' since the model is intended to work on different tasks / data types. ' +
+                        '(Check what you\'ve specified in <project_name>/config.json under "ml_backend" section')
+                else:
+                    raise ValueError(
+                        'Can\'t infer schema for label config ' + label_config +
+                        ' ML backend returns error: ' + response.error_message)
             else:
-                schema = response.response
-                if len(schema) > 1:
-                    logger.warning('ML backend returns multiple schemas for label config ' + label_config + ': ' +
-                                   schema + '\nWe currently support only one schema, so 0th schema is used.')
-                return schema[0]
+                return response.response
+
+    def get_schema(self, project):
+        schema = self.validate(project.label_config)
+        if len(schema) > 1:
+            logger.warning('ML backend returns multiple schemas for label config ' + project.label_config + ': ' +
+                           schema + '\nWe currently support only one schema, so 0th schema is used.')
+        return schema[0]
 
     def clear(self, project):
         if self._api_exists():
